@@ -20,16 +20,15 @@ def create_parser():
 
     parser.add_argument(
         '-v', '--verbose',
-        help='Program logging level. '
-             'Available levels are 10-DEBUG, 20-INFO, 30-WARNING, '
-             '40-ERROR or 50-CRITICAL. The default level is 20-INFO.',
+        help='Program logging level in 10-DEBUG, 20-INFO, 30-WARNING, '
+             '40-ERROR or 50-CRITICAL.',
         type=int, default=20, choices=(10, 20, 30, 40, 50))
 
-    sub_parsers = parser.add_subparsers(dest='command', help='[run]: run simulation routine; '
-                                                             '[plot]: plot simulation results; '
-                                                             '[doc]: quick documentation;'
-                                                             '[prepare]: run the symbolic-to-numeric preparation; '
-                                                             '[misc]: miscellaneous functions.'
+    sub_parsers = parser.add_subparsers(dest='command', help='[run] run simulation routine; '
+                                                             '[plot] plot simulation results; '
+                                                             '[doc] quick documentation; '
+                                                             '[prepare] run the symbolic-to-numeric preparation; '
+                                                             '[misc] miscellaneous functions.'
                                         )
 
     run = sub_parsers.add_parser('run')
@@ -50,7 +49,8 @@ def create_parser():
     run.add_argument('--convert-all', help='Convert to format with all templates.', type=str, default='',
                      nargs='?')
     run.add_argument('--add-book', help='Add a template workbook for the specified model.', type=str)
-    run.add_argument('--state-matrix', help='export state matrix to a .mat file', action='store_true')
+    run.add_argument('--state-matrix', help='Export state matrix to a .mat file. Need to run with `-r eig`',
+                     action='store_true')
     run.add_argument('--profile', action='store_true', help='Enable Python cProfiler')
 
     plot = sub_parsers.add_parser('plot')
@@ -62,6 +62,8 @@ def create_parser():
     plot.add_argument('--ymax', type=float, help='y axis maximum value')
     plot.add_argument('--ymin', type=float, help='y axis minimum value')
     plot.add_argument('--find', type=str, help='find variable indices that matches the given pattern')
+    plot.add_argument('--xargs', type=str, help='find variable indices and return as a shell argument to be '
+                                                'used with "| xargs andes plot"')
     plot.add_argument('--exclude ', type=str, help='exclude pattern in find')
     plot.add_argument('-x', '--xlabel', type=str, help='manual x-axis text label')
     plot.add_argument('-y', '--ylabel', type=str, help='y-axis text label')
@@ -101,19 +103,17 @@ def preamble():
     Log the ANDES command-line preamble at the `logging.INFO` level
     """
     from andes import __version__ as version
-    logger.info('ANDES {ver} (Git commit id {b}, Python {p} on {os})'
-                .format(ver=version[:5], b=version[-8:],
-                        p=platform.python_version(),
-                        os=platform.system()))
-    try:
-        username = os.getlogin() + ', '
-    except OSError:
-        username = ''
 
-    logger.info('Session: {}{}'.format(username, strftime("%m/%d/%Y %I:%M:%S %p")))
-    logger.info('This program comes with ABSOLUTELY NO WARRANTY.')
+    py_version = platform.python_version()
+    system_name = platform.system()
+    date_time = strftime('%m/%d/%Y %I:%M:%S %p')
+    logger.info("\n"
+                rf"    _           _         | Version {version}" + '\n'
+                rf"   /_\  _ _  __| |___ ___ | Python {py_version} on {system_name}, {date_time}" + '\n'
+                rf"  / _ \| ' \/ _` / -_|_-< | " + "\n"
+                rf' /_/ \_\_||_\__,_\___/__/ | This program comes with ABSOLUTELY NO WARRANTY.' + '\n')
+
     logger.debug(f'Logging to file {find_log_path(logging.getLogger("andes"))[0]}')
-    logger.info('')
 
 
 def main():
@@ -126,11 +126,13 @@ def main():
                   file=True,
                   log_path=get_log_dir(),
                   )
-    preamble()
     logger.debug(args)
 
     module = importlib.import_module('andes.main')
 
+    if args.command != 'plot':
+        preamble()
+
     if args.command is None:
         parser.parse_args(sys.argv.append('--help'))
 
