@@ -1,7 +1,8 @@
 from andes.core.var import Algeb, State
-from typing import Optional
-from andes.core.discrete import HardLimiter, AntiWindupLimiter
+from typing import Optional, Iterable
+from andes.core.discrete import AntiWindupLimiter
 from andes.core.service import ConstService
+from andes.core.triplet import JacTriplet
 
 
 class DummyValues(object):
@@ -94,20 +95,7 @@ class Block(object):
         self.info = info
         self.owner = None
         self.vars: dict = dict()
-
-        self.ifx, self.jfx, self.vfx = list(), list(), list()
-        self.ify, self.jfy, self.vfy = list(), list(), list()
-        self.igx, self.jgx, self.vgx = list(), list(), list()
-        self.igy, self.jgy, self.vgy = list(), list(), list()
-        self.itx, self.jtx, self.vtx = list(), list(), list()
-        self.irx, self.jrx, self.vrx = list(), list(), list()
-
-        self.ifxc, self.jfxc, self.vfxc = list(), list(), list()
-        self.ifyc, self.jfyc, self.vfyc = list(), list(), list()
-        self.igxc, self.jgxc, self.vgxc = list(), list(), list()
-        self.igyc, self.jgyc, self.vgyc = list(), list(), list()
-        self.itxc, self.jtxc, self.vtxc = list(), list(), list()
-        self.irxc, self.jrxc, self.vrxc = list(), list(), list()
+        self.triplets = JacTriplet()
 
     def __setattr__(self, key, value):
         # handle sub-blocks by prepending self.name
@@ -131,17 +119,11 @@ class Block(object):
 
     def j_reset(self):
         """
-        Helper function to clear the lists holding the numerical jacobians
-        """
-        self.ifx, self.jfx, self.vfx = list(), list(), list()
-        self.ify, self.jfy, self.vfy = list(), list(), list()
-        self.igx, self.jgx, self.vgx = list(), list(), list()
-        self.igy, self.jgy, self.vgy = list(), list(), list()
+        Helper function to clear the lists holding the numerical Jacobians.
 
-        self.ifxc, self.jfxc, self.vfxc = list(), list(), list()
-        self.ifyc, self.jfyc, self.vfyc = list(), list(), list()
-        self.igxc, self.jgxc, self.vgxc = list(), list(), list()
-        self.igyc, self.jgyc, self.vgyc = list(), list(), list()
+        This function should be only called once at the beginning of ``j_numeric`` in blocks.
+        """
+        self.triplets.clear_ijv()
 
     def define(self):
         """
@@ -245,6 +227,16 @@ class Block(object):
         """Return the class name."""
         return self.__class__.__name__
 
+    @staticmethod
+    def enforce_tex_name(fields):
+        """Enforce tex_name is not None"""
+        if not isinstance(fields, Iterable):
+            fields = [fields]
+
+        for field in fields:
+            if field.tex_name is None:
+                raise NameError(f'tex_name for <{field.name}> cannot be None')
+
 
 class PIController(Block):
     """
@@ -271,7 +263,7 @@ class PIController(Block):
         self.ki = ki
 
         self.xi = State(info="Integration value of PI controller")
-        self.y = Algeb(info="Integration value of PI controller")
+        self.y = Algeb(info="Output value")
 
         self.vars = {'xi': self.xi, 'y': self.y}
 
@@ -307,7 +299,7 @@ class PIControllerNumeric(Block):
         self.ki = ki
 
         self.xi = State(info="Integration value of PI controller")
-        self.y = Algeb(info="Integration value of PI controller")
+        self.y = Algeb(info="Output value")
 
         self.vars = {'xi': self.xi, 'y': self.y}
 
@@ -320,17 +312,10 @@ class PIControllerNumeric(Block):
     def j_numeric(self):
         self.j_reset()
 
-        self.ifyc.append(self.xi.a)
-        self.jfyc.append(self.u.a)
-        self.vfyc.append(-self.ki.v)
-
-        self.igyc.append(self.y.a)
-        self.jgyc.append(self.u.v)
-        self.vgyc.append(-self.kp.v)
-
-        self.igxc.append(self.y.a)
-        self.jgxc.append(self.xi.a)
-        self.vgxc.append(1)
+        # TODO: test the following code
+        self.triplets.append_ijv('fyc', self.xi.id, self.u.id, -self.ki.v)
+        self.triplets.append_ijv('gyc', self.y.id, self.u.id, -self.kp.v)
+        self.triplets.append_ijv('gxc', self.y.id, self.xi.id, 1)
 
     def define(self):
         """Skip the symbolic definition"""
@@ -359,6 +344,8 @@ class Washout(Block):
         else:
             self.K = K
 
+        self.enforce_tex_name((self.K, self.T))
+
         self.KT = ConstService(info='Constant K/T',
                                tex_name=f'({self.K.tex_name}/{self.T.tex_name})',
                                v_str=f'{self.K.name} / {self.T.name}')
@@ -410,14 +397,14 @@ class Lag(Block):
     """
     def __init__(self, u, T, K, name=None, info='Lag transfer function'):
         super().__init__(name=name, info=info)
-
+        self.u = u
+        self.T = T
         if isinstance(K, (int, float)):
             self.K = DummyValues(K)
         else:
             self.K = K
 
-        self.T = T
-        self.u = u
+        self.enforce_tex_name((self.K, self.T))
         self.x = State(info='State in lag transfer function', tex_name="x'")
 
         self.vars = {'x': self.x}
@@ -472,6 +459,8 @@ class LagAntiWindup(Block):
         self.lower = lower
         self.upper = upper
 
+        self.enforce_tex_name((self.T, self.K))
+
         self.x = State(info='State in lag transfer function', tex_name="x'")
         self.lim = AntiWindupLimiter(u=self.x, lower=self.lower, upper=self.upper, tex_name='lim')
 
@@ -526,6 +515,8 @@ class LeadLag(Block):
         self.u = u
         self.safe_div = safe_div  # TODO: implement me
 
+        self.enforce_tex_name((self.T1, self.T2))
+
         self.x = State(info='State in lead-lag transfer function', tex_name="x'")
         self.y = Algeb(info='Output of lead-lag transfer function', tex_name=r'y')
         self.vars = {'x': self.x, 'y': self.y}
@@ -575,11 +566,12 @@ class LeadLagLimit(Block):
         self.u = u
         self.lower = lower
         self.upper = upper
+        self.enforce_tex_name((self.T1, self.T2))
 
         self.x = State(info='State in lead-lag transfer function', tex_name="x'")
         self.ynl = Algeb(info='Output of lead-lag transfer function before limiter', tex_name=r'y_{nl}')
         self.y = Algeb(info='Output of lead-lag transfer function after limiter', tex_name=r'y')
-        self.lim = HardLimiter(u=self.ynl, lower=self.lower, upper=self.upper)
+        self.lim = AntiWindupLimiter(u=self.ynl, lower=self.lower, upper=self.upper)
 
         self.vars = {'x': self.x, 'ynl': self.ynl, 'y': self.y, 'lim': self.lim}
 
@@ -620,6 +612,13 @@ class Piecewise(Block):
     This block takes a list of N points, [x0, x1, ...x_{n-1}] and a list of N+1 functions [fun0, ..., fun_n].
     Inputs in each range (xk, x_{k+1}] applies its corresponding function `fun_k`. The last range (x_{n-1},
     +inf) applies the last function `fun_n`.
+
+    Parameters
+    ----------
+    points : list
+        A list of piecewise points. Need to be provided in the constructor function.
+    funs : list
+        A list of strings for the piecewise functions. Need to be provided in the overloaded `define` function.
     """
     def __init__(self, u, points: list, funs: list, name=None, tex_name=None, info=None):
         super().__init__(name=name, tex_name=tex_name, info=info)
@@ -647,64 +646,3 @@ class Piecewise(Block):
 
         self.y.v_str = pw_fun
         self.y.e_str = f'{pw_fun} - {self.name}_y'
-
-
-class MagneticQuadSat(Piecewise):
-    """
-    A saturation block takes an input signal and outputs the saturated signal.
-
-    This block is experimental and has not been fully tested.
-    """
-    def __init__(self, u, s10, s12, name=None, tex_name=None, info=None):
-        self.s10 = s10
-        self.s12 = s12
-
-        points = [0, 0.8]
-        c0 = [15, -24, 10]
-        c1 = [-27.5, 50, -22.5]
-        c2 = [12.5, -25, 12.5]
-
-        self.c0 = ConstService(v_str=f'0.8*{c0[0]} + {c0[1]} * (1 - {s10.name}) + 1.2 * {c0[2]} * (1-{s12.name})',
-                               tex_name='c_0', info='Constant coefficient in quadratic saturation')
-        self.c1 = ConstService(v_str=f'0.8*{c1[0]} + {c1[1]} * (1 - {s10.name}) + 1.2 * {c1[2]} * (1-{s12.name})',
-                               tex_name='c_1')
-        self.c2 = ConstService(v_str=f'0.8*{c2[0]} + {c2[1]} * (1 - {s10.name}) + 1.2 * {c2[2]} * (1-{s12.name})',
-                               tex_name='c_2')
-
-        super().__init__(u=u, points=points, funs=None, name=name, tex_name=tex_name, info=info)
-
-        self.vars.update({'c0': self.c0, 'c1': self.c1, 'c2': self.c2})
-
-    def define(self):
-        """Define the quadratic saturation function."""
-        self.funs = ['0',
-                     f'{self.u.name}',
-                     f'{self.name}_c0 + {self.name}_c1*{self.u.name} + {self.name}_c2 * {self.u.name}**2'
-                     ]
-        super().define()
-
-
-class MagneticExpSat(Piecewise):
-    """
-    Exponential saturation function for generator magnetization
-
-    This block is experimental and has not been fully tested.
-    """
-    def __init__(self, u, s10, s12, name=None, tex_name=None, info=None):
-        self.s10 = s10
-        self.s12 = s12
-
-        points = [0, 1.0, 1.2]
-        self.c = ConstService(v_str=f'log({s12.name} / {s10.name}) / log(1.2)')
-
-        super().__init__(u=u, points=points, funs=None, name=name, tex_name=tex_name, info=info)
-        self.vars.update({'c': self.c})
-
-    def define(self):
-        """Define the exponential saturation function."""
-        self.funs = ['0',
-                     f'{self.s10.name} * {self.u.name} ^ {self.name}_c',
-                     f'{self.s10.name} * {self.u.name} ^ {self.name}_c',
-                     f'{self.s10.name} * {self.u.name} ^ {self.name}_c'
-                     ]
-        super().define()
