@@ -64,7 +64,10 @@ class BusData(ModelData):
 
 class Bus(Model, BusData):
     """
-    AC Bus model developed using the symbolic framework
+    AC Bus model.
+
+    Power balance equation have the form of ``load - injection = 0``.
+    Namely, load is positively summed, while injections are negative.
     """
 
     def __init__(self, system=None, config=None):
