@@ -3,7 +3,7 @@ Synchronous generator classes
 """
 import logging
 from andes.core.model import Model, ModelData
-from andes.core.param import IdxParam, NumParam
+from andes.core.param import IdxParam, NumParam, ExtParam
 from andes.core.var import Algeb, State, ExtAlgeb
 from andes.core.discrete import LessThan
 from andes.core.service import ConstService, ExtService  # NOQA
@@ -24,7 +24,6 @@ class GENBaseData(ModelData):
         self.coi = IdxParam(model='COI',
                             info="center of inertia index",
                             )
-
         self.Sn = NumParam(default=100.0,
                            info="Power rating",
                            tex_name='S_n',
@@ -103,7 +102,7 @@ class GENBase(Model):
                            unit='pu (Hz)',
                            v_str='u',
                            tex_name=r'\omega',
-                           e_str='(u / M ) * (tm - te - D * (omega - 1))')
+                           e_str='(u / M) * (tm - te - D * (omega - 1))')
 
         # network algebraic variables
         self.a = ExtAlgeb(model='Bus',
@@ -165,6 +164,12 @@ class GENBase(Model):
                         tex_name=r'v_f'
                         )
 
+        self.subidx = ExtParam(model='StaticGen',
+                               src='subidx',
+                               indexer=self.gen,
+                               tex_name='idx_{sub}',
+                               export=False,
+                               )
         # ----------service consts for initialization----------
         self.p0 = ExtService(model='StaticGen',
                              src='p',
