@@ -107,7 +107,7 @@ class EIG(BaseRoutine):
 
         return self.mu, self.part_fact
 
-    def run(self):
+    def run(self, **kwargs):
         ret = False
         system = self.system
 
