@@ -21,10 +21,10 @@ class TDS(BaseRoutine):
         self.config.add(OrderedDict((('tol', 1e-4),
                                      ('t0', 0.0),
                                      ('tf', 20.0),
-                                     ('fixt', 1),
-                                     ('tstep', 1/30),  # recommended step size
-                                     ('max_iter', 15),
+                                     ('fixt', 1),       # use fixed time step
                                      ('shrinkt', 1),    # shrink step size if `max_iter` is reached
+                                     ('tstep', 1/30),   # fixed step size / initial step size
+                                     ('max_iter', 15),
                                      )))
         # overwrite `tf` from command line
         if system.options.get('tf') is not None:
@@ -81,9 +81,9 @@ class TDS(BaseRoutine):
         _, s1 = elapsed(t0)
 
         if self.initialized is True:
-            logger.info(f"Initialization successful in {s1}.")
+            logger.info(f"Initialization was successful in {s1}.")
         else:
-            logger.info(f"Initialization error in {s1}.")
+            logger.info(f"Initialization failed in {s1}.")
 
         if system.dae.n == 0:
             tqdm.write('No dynamic component loaded.')
@@ -98,8 +98,9 @@ class TDS(BaseRoutine):
 
         """
         out = list()
+        out.append('')
         out.append('-> Time Domain Simulation Summary:')
-        out.append(f'Sparse Solver: {self.config.sparselib.upper()}')
+        out.append(f'Sparse Solver: {self.solver.sparselib.upper()}')
         out.append(f'Simulation time: {self.config.t0}-{self.config.tf}s')
         if self.config.fixt == 1:
             out.append(f'Fixed step size: h={self.config.tstep:.4g}s')
@@ -109,28 +110,34 @@ class TDS(BaseRoutine):
         out_str = '\n'.join(out)
         logger.info(out_str)
 
-    def run(self, verbose=False):
+    def run(self, disable_pbar=False, **kwargs):
         """
         Run the implicit numerical integration for TDS.
 
         Parameters
         ----------
-        verbose : bool
-            verbosity flag for single integration steps
+        disable_pbar : bool
+            True to disable progress bar
         """
         system = self.system
         dae = self.system.dae
         config = self.config
 
+        ret = False
+        if system.PFlow.converged is False:
+            logger.warning('Power flow not solved. Simulation will not continue.')
+            return ret
+
         self.summary()
         self._initialize()
-        self.pbar = tqdm(total=100, ncols=70, unit='%', file=sys.stdout)
+        self.pbar = tqdm(total=100, ncols=70, unit='%', file=sys.stdout, disable=disable_pbar)
 
         t0, _ = elapsed()
         while (system.dae.t < self.config.tf) and (not self.busted):
             if self.calc_h() == 0:
                 self.pbar.close()
                 logger.error(f"Simulation terminated at t={system.dae.t:.4f}.")
+                ret = False
                 break
 
             if self.callpert is not None:
@@ -154,15 +161,19 @@ class TDS(BaseRoutine):
                 system.vars_to_models()
 
         self.pbar.close()
+        delattr(self, 'pbar')  # removed `pbar` so that System can be dilled
+
         _, s1 = elapsed(t0)
         logger.info(f'Simulation completed in {s1}.')
-
         system.TDS.save_output()
+        ret = True
 
         # load data into ``TDS.plotter`` in the notebook mode
         if is_notebook():
             self.load_plotter()
 
+        return ret
+
     def load_plotter(self):
         """
         Manually load a plotter into ``TDS.plotter``.
