@@ -276,9 +276,7 @@ class System(object):
             # initialize variables second
             mdl.initialize()
 
-            # Might need to relay data back and forth ????
-            # send data back and forth
-            # TODO: re-think over the adder-setter approach
+            # TODO: re-think over the adder-setter approach and reduce data copy
             self.vars_to_dae()
             self.vars_to_models()
 
@@ -306,6 +304,16 @@ class System(object):
                 if isinstance(item, AntiWindupLimiter):
                     self.antiwindups.append(item)
 
+    def link_ext_param(self, model):
+        for instance in model.params_ext.values():
+            ext_name = instance.model
+            ext_model = self.__dict__[ext_name]
+
+            try:
+                instance.link_external(ext_model)
+            except IndexError:
+                raise IndexError(f'Model <{model.class_name}> param <{instance.name}> link parameter error')
+
     def calc_pu_coeff(self):
         """
         Perform per unit value conversion.
@@ -317,17 +325,7 @@ class System(object):
 
         for mdl in self.models.values():
             # get external parameters with `link_external` and then calculate the pu coeff
-            for instance in mdl.params_ext.values():
-                ext_name = instance.model
-                try:
-                    ext_model = self.__dict__[ext_name]
-                except KeyError:
-                    raise KeyError(f'<{ext_name}> is not a model or group name.')
-
-                try:
-                    instance.link_external(ext_model)
-                except IndexError:
-                    raise IndexError(f'Model <{mdl.class_name}> param <{instance.name}> link parameter error')
+            self.link_ext_param(mdl)
 
             # default Sn to Sb if not provided. Some controllers might not have Sn or Vn.
             if 'Sn' in mdl.params:
@@ -723,8 +721,6 @@ class System(object):
         """
         Collect indices into `RefParam` for all models.
         """
-        # FIXME: too many safe-checking here. Even the model can be non-existent.
-
         for model in self.models.values():
             for ref in model.ref_params.values():
                 ref.v = [list() for _ in range(model.n)]
@@ -752,11 +748,12 @@ class System(object):
                         dest_model.ref_params[n].v[uid].append(model_idx)
 
     def _generate_pycode_file(self):
-        """Generate empty files for storing lambdified Python code (TODO)"""
+        """
+        Generate empty files for storing lambdified Python code (TODO)
+        """
         self._call_models_method('generate_pycode_file', self.models)
 
     def _generate_initializers(self):
-        # TODO: consider both JIT and non-JIT models
         self._call_models_method('generate_initializers', self.models)
 
     def _generate_symbols(self):
@@ -879,7 +876,9 @@ class System(object):
         self._call_models_method('e_clear', models)
 
     def remove_pycapsule(self):
-        """Remove PyCapsule objects in solvers"""
+        """
+        Remove PyCapsule objects in solvers.
+        """
         for r in self.routines.values():
             r.solver.remove_pycapsule()
 
@@ -961,8 +960,9 @@ class System(object):
             file already exists.
         """
         if file_path is None:
-            home_dir = os.path.expanduser('~')
-            file_path = os.path.join(home_dir, '.andes', 'andes.rc')
+            andes_path = os.path.join(os.path.expanduser('~'), '.andes')
+            os.makedirs(andes_path, exist_ok=True)
+            file_path = os.path.join(andes_path, 'andes.rc')
 
         elif os.path.isfile(file_path):
             choice = input(f'Config file {file_path} already exist. Overwrite? [y/N]').lower()
@@ -974,7 +974,7 @@ class System(object):
         with open(file_path, 'w') as f:
             conf.write(f)
 
-        logger.info(f'Config: written to {file_path}')
+        logger.info(f'Config written to "{file_path}"')
 
     def supported_models(self):
         """
