@@ -1,37 +1,63 @@
 import logging
-from collections import OrderedDict, defaultdict
+from collections import OrderedDict
+from andes.core.triplet import JacTriplet
 from andes.shared import pd, np, spmatrix, jac_names
 
 logger = logging.getLogger(__name__)
 
 
 class DAETimeSeries(object):
+    """
+    DAE time series data
+    """
     def __init__(self, dae=None):
         self.dae = dae
+
+        # internal dict storage
         self._data = OrderedDict()
         self._z = OrderedDict()
 
         self.t = np.array([])
         self.xy = np.array([])
         self.z = np.array([])
+
+        # data frame members
         self.df = None
         self.df_z = None
 
+        # flags
+        self._need_unpack = True
+
+    @property
+    def x(self):
+        return self.xy[:, 0:self.dae.n+1]
+
+    @property
+    def y(self):
+        indices = [0] + list(range(self.dae.n + 1, self.dae.n + self.dae.m + 1))
+        return self.xy[:, indices]
+
     @property
     def txyz(self):
         """
         Return the values of [t, x, y, z] in an array.
         """
+        self.unpack()
+        if len(self._z):
+            return np.hstack((self.t.reshape((-1, 1)), self.xy, self.z))
+        else:
+            return np.hstack((self.t.reshape((-1, 1)), self.xy))
+
+    def unpack(self):
+        """
+        Unpack data and make DataFrames and arrays.
+        """
         self.df = pd.DataFrame.from_dict(self._data, orient='index', columns=self.dae.xy_name)
         self.t = self.df.index.to_numpy()
         self.xy = self.df.to_numpy()
 
-        if len(self._z):
-            self.df_z = pd.DataFrame.from_dict(self._z, orient='index', columns=self.dae.z_name)
-            self.z = self.df_z.to_numpy()
-            return np.hstack((self.t.reshape((-1, 1)), self.xy, self.z))
-        else:
-            return np.hstack((self.t.reshape((-1, 1)), self.xy))
+        self.df_z = pd.DataFrame.from_dict(self._z, orient='index', columns=self.dae.z_name)
+        self.z = self.df_z.to_numpy()
 
     def store_txyz(self, t, xy, z=None):
         """
@@ -64,21 +90,15 @@ class DAE(object):
         self.x, self.y, self.z = np.array([]), np.array([]), np.array([])
         self.f, self.g = np.array([]), np.array([])
 
-        self.fx = None
-        self.fy = None
-        self.gx = None
-        self.gy = None
-        self.tx = None
-        self.rx = None
+        self.fx, self.fy = None, None
+        self.gx, self.gy = None, None
+        self.rx, self.tx = None, None
 
         self.x_name, self.x_tex_name = [], []
         self.y_name, self.y_tex_name = [], []
         self.z_name, self.z_tex_name = [], []
 
-        # ----- indices of sparse matrices -----
-        self.ijac = defaultdict(list)
-        self.jjac = defaultdict(list)
-        self.vjac = defaultdict(list)
+        self.triplets = JacTriplet()
 
     def clear_ts(self):
         self.ts = DAETimeSeries(self)
@@ -110,10 +130,10 @@ class DAE(object):
         self.z = np.zeros(self.n)
 
     def clear_ijv(self):
-        for jname in jac_names:
-            self.ijac[jname] = list()
-            self.jjac[jname] = list()
-            self.vjac[jname] = list()
+        """
+        Clear stored triplets.
+        """
+        self.triplets.clear_ijv()
 
     def restore_sparse(self):
         """
@@ -173,9 +193,9 @@ class DAE(object):
         val : np.ndarray
             all values
         """
-        self.ijac[name] = row
-        self.jjac[name] = col
-        self.vjac[name] = val
+        self.triplets.ijac[name] = row
+        self.triplets.jjac[name] = col
+        self.triplets.vjac[name] = val
 
     def build_pattern(self, name):
         """
@@ -188,7 +208,9 @@ class DAE(object):
         name : name
             jac name
         """
-        self.__dict__[name] = spmatrix(self.vjac[name], self.ijac[name], self.jjac[name],
+        self.__dict__[name] = spmatrix(self.triplets.vjac[name],
+                                       self.triplets.ijac[name],
+                                       self.triplets.jjac[name],
                                        self.get_size(name), 'd')
 
     def _compare_pattern(self, name):
@@ -200,7 +222,9 @@ class DAE(object):
 
             self.dae._compare_pattern(j_name)
         """
-        self.__dict__[f'{name}_tpl'] = spmatrix(self.vjac[name], self.ijac[name], self.jjac[name],
+        self.__dict__[f'{name}_tpl'] = spmatrix(self.triplets.vjac[name],
+                                                self.triplets.ijac[name],
+                                                self.triplets.jjac[name],
                                                 self.get_size(name), 'd')
         m_before = self.__dict__[f'{name}_tpl']
         m_after = self.__dict__[name]
@@ -263,10 +287,21 @@ class DAE(object):
         mapping = {'f': 'x', 'g': 'y', 'x': 'x', 'y': 'y', 'z': 'z'}
         return self.__dict__[mapping[arr] + '_name']
 
-    def print_array(self, name, value=None):
-        if value is None:
-            value = self.__dict__[name]
-        res = "\n".join("{:15s} {:<10.4g}".format(x, y) for x, y in zip(self.get_name(name), value))
+    def print_array(self, name, values=None, tol=None):
+        if values is None:
+            values = self.__dict__[name]
+
+        indices = list(range(len(values)))
+        if tol is not None:
+            indices = np.where(abs(values) >= tol)
+            values = values[indices]
+
+        name_list = np.array(self.get_name(name))[indices]
+
+        if not len(name_list):
+            return
+        logger.info(f"Debug Print at {self.t:.4f}")
+        res = "\n".join("{:15s} {:<10.4g}".format(x, y) for x, y in zip(name_list, values))
         logger.info(res)
 
     def write_lst(self, lst_path):
