@@ -4,9 +4,9 @@ import andes
 
 class TestCodegen(unittest.TestCase):
     def setUp(self) -> None:
-        self.ss = andes.main.prepare()
+        self.ss = andes.main.prepare(quick=True)
 
-    def test_docs(self):
+    def test_docs(self) -> None:
         out = ''
         for group in self.ss.groups.values():
-            out += group.doc_all(export='rest')
+            out += group.doc_all()
